# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Build using cmake from Fedora 30, as per the Fedora package
%if 0%{?fedora} < 30 && 0%{?rhel} < 9
%global use_cmake 0
%else
%global use_cmake 1
%endif

Summary:	A library that performs asynchronous DNS operations
Name:		c-ares
Version:	1.34.2
Release:	1.0.cf.%{__distinit}%{__distvers}
License:	MIT
URL:		https://www.c-ares.org/
Source0:	https://github.com/c-ares/c-ares/releases/download/v%{version}/c-ares-%{version}.tar.gz
Patch0:		c-ares-1.33.1-pkgconfig.patch
%if %{use_cmake}
BuildRequires:	cmake
%endif
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	hardlink
BuildRequires:	make

# %%make_build only defined from EL-7, F-21 onwards
%{!?make_build:%global make_build make %{_smp_mflags}}

%description
c-ares is a C library that performs DNS requests and name resolves
asynchronously. c-ares is a fork of the library named 'ares', written
by Greg Hudson at MIT.

%package devel
Summary:	Development files for c-ares
Requires:	%{name} = %{version}-%{release}

# Fix compatibility with new cmake macros from Fedora 33
# (which might get backported as far as Fedora 31)
%global _vpath_builddir $RPM_BUILD_DIR/c-ares-%{version}

%description devel
This package contains the header files and libraries needed to
compile applications or shared objects that use c-ares.

%prep
%setup -q

# Fix libcares.pc libdir with cmake build
%patch -P 0

%build
%if %{use_cmake}
%{cmake} -DCMAKE_INSTALL_LIBDIR:PATH="%{_libdir}" -DCARES_BUILD_TOOLS:BOOL=OFF .
%else
%configure \
	--disable-dependency-tracking \
	--disable-silent-rules \
	--disable-static \
	--disable-tests \
	--enable-shared
%endif
%{make_build}

%install
%{make_install}
rm -f %{buildroot}%{_libdir}/libcares.la

# hardlink identical manpages together
hardlink -cv %{buildroot}%{_mandir}/man3/ares_*.3*

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license LICENSE.md
%doc AUTHORS README.md RELEASE-NOTES.md
%{_libdir}/libcares.so.2
%{_libdir}/libcares.so.2.*

%files devel
%{_includedir}/ares.h
%{_includedir}/ares_build.h
%{_includedir}/ares_dns.h
%{_includedir}/ares_dns_record.h
%{_includedir}/ares_nameser.h
%{_includedir}/ares_version.h
%if %{use_cmake}
%{_libdir}/cmake/c-ares/
%endif
%{_libdir}/libcares.so
%{_libdir}/pkgconfig/libcares.pc
%{_mandir}/man3/ares_*.3*

%changelog
* Wed Oct 16 2024 Paul Howarth <paul@city-fan.org> - 1.34.2-1.0.cf
- Update to 1.34.2
  - This release contains a fix for downstream packages detecting the c-ares
    version based on the contents of the header file rather than the
    distributed pkgconf or cmake files

* Mon Oct 14 2024 Paul Howarth <paul@city-fan.org> - 1.34.1-1.0.cf
- Update to 1.34.1
  This is a feature and bugfix release
  Features:
  - adig: Read arguments from adigrc (GH#856)
  - Add new pending write callback optimization via 'ares_set_pending_write_cb'
    (GH#857)
  * New function 'ares_process_fds()' (GH#875)
  - Failed servers should be probed rather than redirecting queries, which could
    cause unexpected latency (GH#877)
  - adig: Rework command line arguments to mimic dig from bind (GH#890)
  - Add new method for overriding network functions
    'ares_set_socket_function_ex()' to properly support all new functionality
    (GH#894)
  - Fix regression with custom socket callbacks due to DNS cookie support
    (GH#895)
  - ares_socket: Set IP_BIND_ADDRESS_NO_PORT on ares_set_local_ip* tcp sockets
    (GH#887)
  - URI parser/writer for ares_set_servers_csv()/ares_get_servers_csv()
    (GH#882)
  Changes:
  - Connection handling modularization (GH#857, GH#876)
  - Expose library/utility functions to tools (GH#860)
  - Remove 'ares__' prefix, just use 'ares_' for internal functions' (GH#872)
  Bugfixes:
  - Fix: Potential WIN32_LEAN_AND_MEAN redefinition (GH#869)
  - Fix googletest v1.15 compatibility (GH#874)
  - Fix pkgconfig thread dependencies (GH#884)

* Wed Aug 28 2024 Paul Howarth <paul@city-fan.org> - 1.33.1-1.0.cf
- Update to 1.33.1
  This is a bugfix release
  Bugfixes:
  - Work around systemd-resolved quirk that returns unexpected codes for single
    label names; also adds test cases to validate the work around works and
    will continue to work in future releases (GH#863)
    See also https://github.com/systemd/systemd/issues/34101
  - Fix sysconfig ndots default value; also adds containerized test case to
    prevent future regressions (GH#862)
  - Fix blank DNS name returning error code rather than valid record for
    commands like: 'adig -t SOA .'; also adds test case to prevent future
    regressions
  - Fix calculation of query times > 1s
  - Fix building on old Linux releases that don't have 'TCP_FASTOPEN_CONNECT'
  - Fix minor Android build warnings (GH#848)

* Tue Aug  6 2024 Paul Howarth <paul@city-fan.org> - 1.33.0-1.0.cf
- Update to 1.33.0
  This is a feature and bugfix release
  Features:
  - Add DNS cookie support (RFC7873+RFC9018) to help prevent off-path cache
    poisoning attacks (GH#833)
  - Implement TCP FastOpen (TFO) RFC7413, which will make TCP reconnects 0-RTT
    on supported systems (GH#840)
  Changes:
  - Reorganize source tree (GH#822)
  - Refactoring of connection handling to prevent code duplication (GH#839)
  - New dynamic array data structure to prevent simple logic flaws in array
    handling in various code paths (GH#841)
  Bugfixes:
  - 'ares_destroy()' race condition during shutdown due to missing lock (GH#831)
  - Android: Preserve thread name after attaching it to JVM (GH#838)
  - Windows UWP (Store) support fix (GH#845)
- Test for TCP_FASTOPEN_CONNECT rather than MSG_FASTOPEN (GH#850)

* Thu Jul 25 2024 Paul Howarth <paul@city-fan.org> - 1.32.3-1.0.cf
- Update to 1.32.3
  This is a bugfix release
  Changes:
  - Prevent complex recursion during query requeuing and connection clean-up
    for stability
  - Better propagate error codes in requeue situations
  - Try to prevent SIGPIPE from being generated and delivered to integrations
  Bugfixes:
  - Windows: Rework EventThread AFD code for better stability (GH#811)
  - Windows: If an IP address was detected to have changed, it could lead to a
    crash due to a bad pointer (regression introduced in 1.31.0)
  - Windows: Use 'QueryPerformanceCounters()' instead of 'GetTickCount64()' for
    better time accuracy (~15ms -> ~1us)
  - Windows 32-bit config change callback needs to be tagged as 'stdcall',
    otherwise it could result in a crash
  - Tests that need accurate timing should not depend on internal symbols as
    there are C++ equivalents in 'std::chrono' (GH#809)
  - Kqueue (MacOS, *BSD): If the open socket count exceeded 8 (unlikely), it
    would try to allocate a new buffer that was too small
  - Missing manpage for 'ares_dns_record_set_id()'
  - Memory leak in 'ares__hosts_entry_to_hostent()' due to allocation strategy
    (GH#824)
  - UDP write failure detected via ICMP unreachable should trigger faster
    failover (GH#821)
  - Fix pycares test case regression due to wrong error code being returned
    (regression from 1.31.0) (GH#820)
  - Fix possible Windows crash during 'ares_destroy()' when using event threads
  - 'ARES_OPT_MAXTIMEOUTMS' wasn't being honored in all cases

* Mon Jul  8 2024 Paul Howarth <paul@city-fan.org> - 1.32.1-1.0.cf
- Update to 1.32.1
  This is a feature and bugfix release
  Features:
  - Add support for DNS 0x20 to help prevent cache poisoning attacks, enabled
    by specifying 'ARES_FLAG_DNS0x20', disabled by default (GH#800)
  - Rework query timeout logic to automatically adjust timeouts based on
    network conditions; the timeout specified is now only used as a hint until
    there is enough history to calculate a more valid timeout (GH#794)
  Changes:
  - Enable Query Cache by default (GH#786)
  - DNS RR TXT strings should not be automatically concatenated as there are
    use cases outside of RFC 7208; in order to maintain ABI compliance, the
    ability to retrieve TXT strings concatenated is retained as well as a new
    API to retrieve the individual strings, which restores behaviour from
    c-ares 1.20.0 (GH#801)
  - Clean up header inclusion logic to make hacking on code easier (GH#797)
  - GCC/Clang: Enable even more strict warnings to catch more coding flaws
  - MSVC: Enable '/W4' warning level (GH#792)
  Bugfixes:
  - Enhance Windows DNS configuration change detection to also detect manual
    DNS configuration changes (GH#785)
  - Various legacy MacOS Build fixes (GH#782)
  - Ndots value of zero in resolv.conf was not being honoured
  - Watt-32 build support had been broken for some time (GH#781)
  - Distribute 'ares_dns_rec_type_tostr' manpage (GH#778)
  - Tests: Fix thread race condition in test cases for EventThread (GH#803)
  - Windows: Fix building with UNICODE (GH#802)
  - Thread Safety: 'ares_timeout()' was missing lock
  - Fix building with DJGPP (32-bit protected mode DOS) (GH#789)
  - Channel lock needs to be recursive to ensure calls into c-ares functions
    can be made from callbacks, otherwise deadlocks will occur (fixes
    regression introduced in 1.32.0)

* Sun Jun  9 2024 Paul Howarth <paul@city-fan.org> - 1.30.0-1.0.cf
- Update to 1.30.0
  This is a maintenance and bugfix release
  Features:
  - Basic support for SIG RR record (RFC 2931/RFC 2535) (GH#773)
  Changes:
  - Validation that DNS strings can only consist of printable ascii characters
    otherwise will trigger a parse failure
  - Windows: use 'GetTickCount64()' for a monotonic timer that does not wrap
  Bugfixes:
  - QueryCache: Fix issue where purging on server changes wasn't working
  - Windows: Fix Y2K38 issue by creating our own 'ares_timeval_t' datatype
    (GH#772)
  - Fix packaging issue affecting MacOS due to a missing header
  - MacOS: Fix UBSAN warnings that are likely meaningless due to alignment
    issues in new MacOS config reader
  - Android: arm 32-bit build failure due to missing symbol
- Upstream release tarballs moved to GitHub

* Sun May 26 2024 Paul Howarth <paul@city-fan.org> - 1.29.0-1.0.cf
- Update to 1.29.0
  This is a feature and bugfix release
  Features:
  - When using 'ARES_OPT_EVENT_THREAD', automatically reload system
    configuration when network conditions change (GH#759)
  - Apple: Rei-mplement DNS configuration reading to more accurately pull DNS
    settings (GH#750)
  - Add observability into DNS server health via a server state callback,
    invoked whenever a query finishes (GH#744)
  - Add server failover retry behaviour, where failed servers are retried with
    small probability after a minimum delay (GH#731)
  Changes:
  - Mark 'ares_channel_t *' as const in more places in the public API (GH#758)
  Bugfixes:
  - Due to a logic flaw, DNS name compression writing was not properly
    implemented, which would result in the name prefix not being written for a
    partial match; this could cause issues in various record types such as MX
    records when using the deprecated API (regression introduced in 1.28.0
    (GH #757))
  - Revert OpenBSD 'SOCK_DNS' flag: it doesn't do what the docs say it does and
    causes c-ares to become non-functional (GH#754)
  - 'ares_getnameinfo()': Loosen validation on 'salen' parameter (GH#752)
  - cmake: Android requires C99 (GH#748)
  - 'ares_queue_wait_empty()' does not honour timeout_ms ≥ 0 (GH#742)

* Tue Apr  2 2024 Paul Howarth <paul@city-fan.org> - 1.28.1-1.0.cf
- Update to 1.28.1
  This is a feature and bugfix release
  Features:
  - Emit warnings when deprecated c-ares functions are used; this can be
    disabled by passing a compiler definition of 'CARES_NO_DEPRECATED' (GH#732)
  - Add function 'ares_search_dnsrec()' to search for records using the new DNS
    record data structures (GH#719)
  - Rework internals to pass around 'ares_dns_record_t' instead of binary data;
    this introduces new public functions of 'ares_query_dnsrec()' and
    'ares_send_dnsrec()' (GH#730)
  Changes:
  - tests: When performing simulated queries, reduce timeouts to make tests run
    faster
  - Replace configuration file parsers with memory-safe parser (GH#725)
  - Remove 'acountry' completely: the manpage might still get installed
    otherwise (GH#718)
  Bugfixes:
  - CMake: Don't overwrite global required libraries/definitions/includes that
    could cause build errors for projects chain building c-ares (GH#729)
  - CMake: Fix chain building if CMAKE runtime paths not set
  - On some platforms, 'netinet6/in6.h' is not included by 'netinet/in.h' and
    needs to be included separately (GH#728)
  - Fix a potential memory leak in 'ares_init()' (GH#724)
  - Some platforms don't have the 'isascii()' function: implement as a macro
    (GH#721)
  - NDots configuration should allow a value of zero (GH#735)
  - 'ares_search()' and 'ares_getaddrinfo()' resolution would fail in 1.28.0
    if no search domains were specified (GH#737)

* Sat Feb 24 2024 Paul Howarth <paul@city-fan.org> - 1.27.0-1.0.cf
- Update to 1.27.0
  This is a security, feature, and bugfix release
  Security:
  - Reading malformatted '/etc/resolv.conf', '/etc/nsswitch.conf' or the
    'HOSTALIASES' file could result in a crash (CVE-2024-25629)
    https://github.com/c-ares/c-ares/security/advisories/GHSA-mg26-v6qh-x48q
  Features:
  - New function 'ares_queue_active_queries()' to retrieve number of in-flight
    queries (GH#712)
  - New function 'ares_queue_wait_empty()' to wait for the number of in-flight
    queries to reach zero (GH#710)
  - New 'ARES_FLAG_NO_DEFLT_SVR' for 'ares_init_options()' to return a failure
    if no DNS servers can be found rather than attempting to use '127.0.0.1';
    This also introduces a new ares status code of 'ARES_ENOSERVER' (GH#713)
  Changes:
  - EDNS packet size should be 1232 as per DNS Flag Day (GH#705)
  Bugfixes:
  - Windows DNS suffix search list memory leak (GH#711)
  - Fix warning due to ignoring return code of 'write()' (GH#709)
  - CMake: Don't override target output locations if not top-level (GH#708)
  - Fix building c-ares without thread support (GH#700)

* Sun Jan 28 2024 Paul Howarth <paul@city-fan.org> - 1.26.0-1.0.cf
- Update to 1.26.0
  This is a feature and bugfix release
  Features:
  - Event Thread support: Integrators are no longer required to monitor the
    file descriptors registered by c-ares for events and call 'ares_process()'
    when enabling the event thread feature via 'ARES_OPT_EVENT_THREAD' passed
    to 'ares_init_options()' (GH#696)
  - Added flags to 'ares_dns_parse()' to force RAW packet parsing (GH#693)
  Changes:
  - Mark 'ares_fds()' as deprecated (GH#691)
  Bugfixes:
  - adig: Differentiate between internal and server errors
  - Autotools: Allow make to override CFLAGS/CPPFLAGS/CXXFLAGS (GH#695)
  - Autotools: Fix building for 32-bit windows due to stdcall symbol mangling
    (GH#689)
  - RR Name should not be sanity checked against the Question (GH#685)
- Hard link identical manpages together to save space

* Wed Jan  3 2024 Paul Howarth <paul@city-fan.org> - 1.25.0-1.0.cf
- Update to 1.25.0
  This is a maintenance release
  Changes:
  - AutoTools: Rewrite build system to be lighter weight and fix issues in some
    semi-modern systems; it is likely this has broken building on some less
    common and legacy OSs, please report issues
  - Rewrite ares_strsplit() as a wrapper for ares__buf_split() for memory
    safety reasons
  - The ahost utility now uses ares_getaddrinfo() and returns both IPv4 and
    IPv6 addresses by default
  - OpenBSD: Add SOCK_DNS flag when creating socket
  Bug Fixes:
  - Tests: Live reverse lookups for Google's public DNS servers no longer
    return results; replace with CloudFlare pubic DNS servers
  - MacOS legacy SDKs require sys/socket.h before net/if.h
  - Connection failures should increment the server failure count first or a
    retry might be enqueued to the same server
  - On systems that don't implement the ability to enumerate network interfaces
    the stubs used the wrong prototype
  - Fix minor warnings and documentation typos
  - Fix support for older GoogleTest versions
  - getrandom() may require sys/random.h on some systems
  - Fix building tests with symbol hiding enabled
- Drop now-redundant optflags patch

* Sun Dec 24 2023 Paul Howarth <paul@city-fan.org> - 1.24.0-1.0.cf
- Update to 1.24.0
  This is a feature and bugfix release
  Features:
  - Add support for IPv6 link-local DNS servers; nameserver formats can now
    accept the %%iface suffix, and a new ares_get_servers_csv() function was
    added to return servers that can contain the link-local interface name
  Changes:
  - Unbundle GoogleTest for test cases; package maintainers will now need to
    require GoogleTest (GMock) as a build dependency if building tests (new
    GoogleTest versions require C++14 or later)
  - Replace nameserver parsing code to use new memory-safe functions
  - Replace the sortlist parser with new memory-safe functions
  - Various warning fixes and dead code removal
  Bug Fixes:
  - Old Linux versions require POSIX_C_SOURCE or _GNU_SOURCE to compile with
    thread safety support
  - A non-responsive DNS server that caused timeouts wouldn't increment the
    failure count, which would lead to other servers not being tried
    (regression introduced in 1.22.0)
  - Some projects that depend on c-ares expect invalid parameter option values
    passed into ares_init_options() to simply be ignored; this behaviour has
    been restored
  - On linux, getrandom() can fail if the kernel doesn't support the syscall:
    fall back to another random source
  - ares_cancel() when performing ares_gethostbyname() or ares_getaddrinfo()
    with AF_UNSPEC, if called after one address class was returned but before
    the other address class, would return ARES_SUCCESS rather than
    ARES_ECANCELLED
- Note: building without cmake is broken in this release
  (https://github.com/c-ares/c-ares/issues/670)

* Mon Dec  4 2023 Paul Howarth <paul@city-fan.org> - 1.23.0-1.0.cf
- Update to 1.23.0
  This is a feature and bugfix release
  Features:
  - Introduce optional (but on by default) thread-safety for the c-ares library;
    this has no API nor ABI implications
  - resolv.conf in modern systems uses attempts and timeouts options instead of
    the old retrans and retry options
  - Query caching support based on TTL of responses: can be enabled via
    ares_init_options() with ARES_OPT_QUERY_CACHE
  Bug Fixes:
  - ares_init_options() for ARES_OPT_UDP_PORT and ARES_OPT_TCP_PORT accept the
    port in host byte order, but it was reading it as network byte order
    (regression introduced in 1.20.0)
  - ares_init_options() for ARES_FLAG_NOSEARCH was not being honored for
    ares_getaddrinfo() or ares_gethostbyname() (regression introduced in
    1.16.0)
  - Autotools MacOS and iOS version check was failing
  - Environment variables passed to c-ares are meant to be an override for
    system configuration (regression introduced in 1.22.0)
  - Spelling fixes as detected by codespell
  - The timeout returned by ares_timeout() was truncated to milliseconds but
    validated to microseconds, which could cause a user to attempt to process
    timeouts prior to the timeout actually expiring
  - CMake was not honoring CXXFLAGS passed in via the environment, which could
    cause compile and link errors with distribution hardening flags during
    packaging
  - Fix Windows UWP and Cygwin compilation
  - ares_set_servers_*() for legacy reasons needs to accept an empty server list
    and zero out all servers, which results in an inoperable channel and thus is
    only used in simulation testing, but we don't want to break users
    (regression introduced in 1.21.0)

* Wed Nov 22 2023 Paul Howarth <paul@city-fan.org> - 1.22.1-1.0.cf
- Update to 1.22.1
  This is a bugfix release
  - Fix /etc/hosts processing performance with all entries using same IP
    address; large hosts files using the same IP address for all entries could
    use exponential time
  - Fix typos in manpages
  - Fix OpenWatcom building

* Wed Nov 15 2023 Paul Howarth <paul@city-fan.org> - 1.22.0-1.0.cf
- Update to 1.22.0
  This is a feature release with some significant internal changes
  Features:
  - ares_reinit() is now implemented to re-read any system configuration and
    immediately apply to an existing ares channel
  - The adig command line program has been rewritten and its format now more
    closely matches that of BIND's dig utility
  - The new DNS message parser and writer functions have now been made public
  - RFC9460 HTTPS and SVCB records are now supported
  - RFC6698 TLSA records are now supported
  - The server list is now internally dynamic and can be changed without
    impacting existing queries
  - Hosts file processing is now cached until the file is detected to be changed
    to speed up repetitive lookups of large hosts files
  Changes:
  - Internally all DNS messages are now written using the new DNS writing
    functions
  - EDNS is now enabled by default
  - Internal cleanups in function prototypes
  Bug Fixes:
  - Randomize retry penalties to prevent thundering herd issues when dns
    servers throttle requests
  - Fix Windows build error for missing if_indextoname()

* Fri Oct 27 2023 Paul Howarth <paul@city-fan.org> - 1.21.0-1.0.cf
- Update to 1.21.0
  This is a bugfix and clean-up release with some significant internal changes
  - Provide better man page cross-links
  - Introduce ares_status_t as an enum rather than using #define list and
    integer data type for internal functions
  - Introduce ares_bool_t datatype rather than using an integer with 0/1 so it
    is clear based on the function prototype what it returns
  - Increase compiler warning levels by default
  - Use size_t and other more proper datatypes internally (rather than int)
  - Many developers have used different code styles over the years; standardize
    on one and use clang-format to enforce the style
  - CMake can now control symbol visibility
  - Replace multiple DNS hand-made parsers with new memory-safe DNS message
    parser
  - Tools: STAYOPEN flag could make tools not terminate
  - Socket callbacks were passed SOCK_STREAM instead of SOCK_DGRAM on udp

* Mon Oct  9 2023 Paul Howarth <paul@city-fan.org> - 1.20.1-1.0.cf
- Update to 1.20.1
  This is a feature and bugfix release with some significant internal changes
  - Update from 1989 MIT license text to modern MIT license text
  - Remove acountry from built tools as nerd.dk is gone
  - Add new ARES_OPT_UDP_MAX_QUERIES configuration option to limit the number of
    queries that can be made from a single ephemeral port
  - Default per-query timeout has been reduced to 2s with a 3x retry count
  - Modernization: start implementing some common data structures that are easy
    to use and hard to misuse, which will make code refactoring easier and
    remove some varied implementations in use; this change also makes
    ares_timeout() more efficient
  - Use SPDX identifiers and a REUSE CI job to verify
  - rand: Add support for getrandom()
  - TCP back to back queries were broken
  - Ensure queries for ares_getaddrinfo() are not requeued during destruction
  - ares_getaddrinfo() should not retry other address classes if one address
    class has already been returned
  - Avoid production of ill-formed result when qualifying a name with the root
    domain
  - Fix missing prefix for CMake generated libcares.pc
  - DNS server ports will now be read from system configuration instead of
    defaulting to port 53
  - Remove some unreachable code
  - Replace usages of sprintf with snprintf
  - Fix Watcom instructions and update Windows URLs
  - Resolve use-after-free issue when TCP connection is terminated before a
    response is returned
  - Reduce number of queries for a load test case to prevent overloading some
    build systems
  - Fix fuzz test build target

* Mon Jun  5 2023 Paul Howarth <paul@city-fan.org> - 1.19.1-1.0.cf
- Update to 1.19.1
  - CVE-2023-32067 (High): 0-byte UDP payload causes Denial of Service
  - CVE-2023-31147 (Moderate): Insufficient randomness in generation of DNS
    query IDs
  - CVE-2023-31130 (Moderate): Buffer Underwrite in ares_inet_net_pton()
  - CVE-2023-31124 (Low): AutoTools does not set CARES_RANDOM_FILE during cross
    compilation
  - Fix uninitialized memory warning in test
  - Turn off IPV6_V6ONLY on Windows to allow IPv4-mapped IPv6 addresses
  - ares_getaddrinfo() should allow a port of 0
  - Fix memory leak in ares_send() on error
  - Fix comment style in ares_data.h
  - Remove unneeded ifdef for Windows
  - Fix typo in ares_init_options.3
  - Re-add support for Watcom compiler
  - Sync ax_pthread.m4 with upstream
  - Windows: Invalid stack variable used out of scope for HOSTS path
  - Sync ax_cxx_compile_stdcxx_11.m4 with upstream to fix uclibc support
- Avoid use of deprecated patch syntax

* Mon Jan 30 2023 Paul Howarth <paul@city-fan.org> - 1.19.0-1.0.cf
- Update to 1.19.0
  Security
  - Stack overflow in ares_set_sortlist(), which is used during c-ares
    initialization and typically provided by an administrator and not an end
    user
  Changes
  - Windows: Drop support for XP and derivatives, which greatly cleans up
    initialization code
  - Add ARES_OPT_HOSTS_FILE similar to ARES_OPT_RESOLVCONF for specifying a
    custom hosts file location
  - Add vcpkg installation instructions
  Bug fixes
  - Fix cross-compilation from Windows to Linux due to CPACK logic
  - Fix memory leak in reading /etc/hosts when using localhost fallback
  - Fix chain building c-ares when libresolv is already included by another
    project
  - File lookup should not immediately abort as there may be other tries due to
    search criteria
  - Asterisks should be allowed in host validation as CNAMEs may reference
    wildcard domains
  - AutoTools build system referenced bad STDC_HEADERS macro
  - Even if one address class returns a failure for ares_getaddrinfo(), we
    should still return the results we have
  - CMake Windows: DLLs did not include resource file to include versions
  - CMake: Guard target creation in exported config
  - Fix ares_getaddrinfo() numerical address resolution with AF_UNSPEC
  - Apple: Fix libresolv configured query times
  - Fix tools and help information
  - Various documentation fixes and clean-ups
  - Add include guards to ares_data.h
  - c-ares could try to exceed maximum number of iovec entries supported by
    system
  - CMake package config generation allow for absolute install paths
  - Intel compiler fixes
  - ares_strsplit bugs
  - The RFC6761 6.3 states localhost subdomains must be offline too

* Sun Jan 23 2022 Paul Howarth <paul@city-fan.org> - 1.18.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Oct 27 2021 Paul Howarth <paul@city-fan.org> - 1.18.1-1.0.cf
- Update to 1.18.1
  Bug fixes:
  - ares_getaddrinfo() would return ai_addrlen of 16 for ipv6 addresses rather
    than sizeof(struct sockaddr_in6)

* Tue Oct 26 2021 Paul Howarth <paul@city-fan.org> - 1.18.0-1.0.cf
- Update to 1.18.0
  Changes:
  - Add support for URI (Uniform Resource Identifier) records via
    ares_parse_uri_reply()
  - Provide ares_nameser.h as a public interface as needed by NodeJS
  - Update URLs from c-ares.haxx.se to c-ares.org
  - During a domain search, treat ARES_ENODATA as ARES_NXDOMAIN so that the
    search process will continue to the next domain in the search
  - Turn ares_gethostbyname() into a wrapper for ares_getaddrinfo() as they
    followed very similar code paths and ares_gethostbyaddr() has some more
    desirable features such as priority sorting and parallel queries for
    AF_UNSPEC
  - ares_getaddrinfo() now contains a name element in the address info
    structure as the last element; this is not an API or ABI break due to the
    structure always being internally allocated and it being the last element
  - ares_parse_a_reply() and ares_parse_aaaa_reply() were nearly identical;
    those now use the same helper functions for parsing rather than having
    their own code
  o RFC6761 Section 6.3 says "localhost" lookups need to be special cased to
    return loopback addresses, and not forward queries to recursive dns servers;
    on Windows this now returns all loopback addresses, whilst on other systems
    it returns 127.0.0.1 or ::1 always, and will never forward a request for
    "localhost" to outside DNS servers
  - Haiki: port
  Bug fixes:
  - Add build to .gitignore
  - z/OS minor update, add missing semicolon in ares_init.c
  - Fix building when latest ax_code_coverage.m4 is imported
  - Work around autotools 'error: too many loops' and other newer autotools
    import related bugs
  - MinGW cross builds need advapi32 link as lower case
  - Cygwin build fix due to containing both socket.h and winsock2.h
  - ares_expand_name should allow underscores (_) as SRV records legitimately use
    them
  - Allow '/' as a valid character for a returned name for CNAME in-addr.arpa
    delegation
  - ares_getaddrinfo() was not honouring HOSTALIASES
  - ares_getaddrinfo() had some test cases disabled due to a bug in the test
    framework itself that has now been resolved
  - Due to Travis-CI becoming unfriendly to open-source, Cirrus-CI has now been
    brought online for automated unit testing

* Tue Aug 10 2021 Paul Howarth <paul@city-fan.org> - 1.17.2-1.0.cf
- Update to 1.17.2
  Security:
  - NodeJS passes NULL for addr and 0 for addrlen to ares_parse_ptr_reply() on
    systems where malloc(0) returns NULL, which would cause a crash
  - When building c-ares with CMake, the RANDOM_FILE would not be set and
    therefore downgrade to the less secure random number generator
  - If ares_getaddrinfo() was terminated by an ares_destroy(), it would cause a
    crash
  - Crash in sortaddrinfo() if the list size equals 0 due to an unexpected DNS
    response
  - Expand number of escaped characters in DNS replies as per RFC1035 5.1 to
    prevent spoofing
  - Perform validation on hostnames to prevent possible XSS due to applications
    not performing validation themselves
  Changes:
  - Use non-blocking /dev/urandom for random data to prevent early startup
    performance issues
  - z/OS port
  - ares_malloc(0) is now defined behaviour (returns NULL) rather than
    system-specific to catch edge cases
  Bug fixes:
  - Fuzz testing files were not distributed with official archives
  - Building tests should not force building of static libraries except on
    Windows
  - Windows builds of the tools would fail if built as static due to a missing
    CARES_STATICLIB definition
  - Relative headers must use double quotes to prevent pulling in a system
    library
  - Fix OpenBSD building by implementing portability updates for including
    arpa/nameser.h
  - Fix building out-of-tree for autotools
  - Make install on MacOS/iOS with CMake was missing the bundle destination so
    libraries weren't actually installed
  - Fix retrieving DNS server configuration on MacOS and iOS if the
    configuration did not include search domains
  - ares_parse_a_reply and ares_parse_aaaa_reply were erroneously using strdup()
    instead of ares_strdup()

* Thu Jul 22 2021 Paul Howarth <paul@city-fan.org> - 1.17.1-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix dist tags for Alma and Rocky Linux

* Tue Feb  2 2021 Paul Howarth <paul@city-fan.org> - 1.17.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Nov 20 2020 Paul Howarth <paul@city-fan.org> - 1.17.1-1.0.cf
- Update to 1.17.1
  Security:
  - Avoid read-heap-buffer-overflow in ares_parse_soa_reply found during
    fuzzing (GH#332, GH#333)
  - Avoid theoretical buffer overflow in RC4 loop comparison (GH#336)
  - Empty hquery->name could lead to invalid memory access (GH#367)
  - ares_parse_{a,aaaa}_reply() could return a larger *naddrttls than was
    passed in (GH#371)
  Changes:
  - Update help information for adig, acountry, and ahost (GH#334)
  - Test Suite now uses dynamic system-assigned ports rather than hardcoded
    ports to prevent failures in containers (GH#346)
  - Detect remote DNS server does not support EDNS using rules from RFC 6891
    (GH#244)
  - Source tree has been reorganized to use a more modern layout (GH#349)
  - Allow parsing of CAA Resource Record (GH#360)
  Bug fixes:
  - readaddrinfo bad sizeof() (GH#331)
  - Test cases should honour HAVE_WRITEV flag, not depend on WIN32 (GH#344)
  - FQDN with trailing period should be queried first (GH#345)
  - ares_getaddrinfo() was returning members of the struct as garbage values if
    unset, and was not honouring ai_socktype and ai_protocol hints (GH#343,
    GH#317)
  - ares_gethostbyname() with AF_UNSPEC and an ip address would fail (GH#204)
  - Properly document ares_set_local_ip4() uses host byte order (GH#368)
- Upstream URLs now require https

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 1.16.1-3.0.cf
- Modernize spec using %%{make_build} and %%{make_install}

* Tue May 12 2020 Paul Howarth <paul@city-fan.org> - 1.16.1-1.0.cf
- Update to 1.16.1
  - Prevent possible use-after-free and double-free in ares_getaddrinfo() if
    ares_destroy() is called prior to ares_getaddrinfo() completing
  - Allow TXT records on CHAOS qclass; used for retrieving things like
    version.bind, version.server, authoris.bind, hostname.bind, and id.server
  - Fix Windows Unicode incompatibilities with ares_getaddrinfo()
  - Silence false cast-align compiler warnings due to valid casts of
    struct sockaddr to struct sockaddr_in and struct sockaddr_in6
  - MacOS should use libresolv for retrieving DNS servers, like iOS
  - CMake build system should populate the INCLUDE_DIRECTORIES property of 
    installed targets
  - Correct macros in use for the ares_getaddrinfo.3 man page

* Fri Mar 13 2020 Paul Howarth <paul@city-fan.org> - 1.16.0-1.0.cf
- Update to 1.16.0
  - Introduction of ares_getaddrinfo() API, which provides similar output
    (including proper sorting as per RFC 6724) to the system native API, but
    utilizes different data structures in order to provide additional
    information such as TTLs and all aliases; please reference the respective
    man pages for usage details
  - Parse SOA records from ns_t_any response
  - CMake: Provide c-ares version in package export file
  - CMake: Add CPACK functionality for DEB and RPM
  - CMake: Generate PDB files during build
  - CMake: Support manpage installation
  - Fix bad expectation in IPv6 localhost test
  - AutoTools: Use XC_CHECK_BUILD_FLAGS instead of XC_CHECK_USER_FLAGS to prevent
    complaints about CPPFLAGS in CFLAGS
  - Fix .onion handling
  - Command line usage was out of date for adig and ahost
  - Typos in manpages
  - If ares_getenv is defined, it must return a value on all platforms
  - If /etc/resolv.conf has invalid lookup values, use the defaults
  - Tests: Separate live tests from SetServers* tests as only live tests should
    require Internet access
  - ares_gethostbyname() should return ENODATA if no valid A or AAAA record is
    found, but a CNAME was found
  - CMake: Rework library function checking to prevent unintended linking with
    system libraries that aren't needed
  - Due to use of inet_addr(), it was not possible to return 255.255.255.255
    from ares_gethostbyname()
  - CMake: Fix building of tests on Windows

* Thu Jan 30 2020 Paul Howarth <paul@city-fan.org> - 1.15.0-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 1.15.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Mar 16 2019 Paul Howarth <paul@city-fan.org> - 1.15.0-3.0.cf
- Use cmake to build (from Fedora 30) so we get cmake helpers (#1687844)

* Wed Feb  6 2019 Paul Howarth <paul@city-fan.org> - 1.15.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Oct 24 2018 Paul Howarth <paul@city-fan.org> - 1.15.0-1.0.cf
- Update to 1.15.0
  - Add ares_init_options() configurability for path to resolv.conf file
  - Ability to exclude building of tools (adig, ahost, acountry) in CMake
  - Android: Support for domain search suffix
  - Report ARES_ENOTFOUND for .onion domain names as per RFC7686
  - AIX build fix for trying to include both nameser_compat.h and
    onameser_compat.h
  - Windows: Improve DNS suffixes extracting from WinNT registry
  - Fix modern GCC warnings
  - Apply the IPv6 server blacklist to all nameserver sources, not just Windows
  - Fix warnings emitted by MSVC when using -W4
  - Prevent changing name servers while queries are outstanding
  - Harden and rationalize c-ares timeout computation
  - Distribute ares_android.h
  - ares_set_servers_csv() on failure should not leave channel in a bad state
  - Add missing docs to distribution
- Fix soname in %%files list to avoid accidental soname bumps

* Mon Sep 10 2018 Paul Howarth <paul@city-fan.org> - 1.14.0-5.0.cf
- Rebuild to sync with Rawhide

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.14.0-1.0.cf
- Update to 1.14.0
  - android: Introduce new ares_library_init_android() call for Oreo support
  - Fix patch for CVE-2017-1000381 not to be overly aggressive
  - win32: Preserve DNS server order returned by Windows when sorting and
    exclude DNS servers in legacy subnets
  - win32: Support most recent Visual Studio 2017
  - gethostbyaddr should fail with ECANCELLED not ENOTFOUND when ares_cancel
    is called
  - win32: Exclude legacy ipv6 subnets
  - android: Applications compiled for Oreo can no longer use
    __system_property_get and must use Java calls to retrieve DNS servers
  - win32: Force use of ANSI functions
  - CMake minimum version is now 3.1
  - ares_gethostbyname.3: Fix callback status values
  - docs: Document WSAStartup requirement
  - Fix a typo in init_by_resolv_conf
  - Android JNI code leaks local references in some cases
  - Force using the ANSI versions of WinAPI functions

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.13.0-4.0.cf
- ldconfig replaced by RPM File Triggers from Fedora 28
- Explicit dependency on pkgconfig no longer needed

* Thu Aug  3 2017 Paul Howarth <paul@city-fan.org> - 1.13.0-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Paul Howarth <paul@city-fan.org> - 1.13.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jun 21 2017 Paul Howarth <paul@city-fan.org> - 1.13.0-1.0.cf
- Update to 1.13.0
  - cmake build system support added
  - Add virtual function set for socket IO: ares_set_socket_functions
  - CVE-2017-1000381: c-ares NAPTR parser out of bounds access
  - macos: Do not set HAVE_CLOCK_GETTIME_MONOTONIC
  - test: Check ares_create_query with too-long name
  - dist: Add ares_library_initialized.* to the tarball
  - Fix build on OpenBSD
  - dist: Ship msvc_ver.inc too
  - test: Add gTest/gMock files to SOURCES
  - test: Add fuzz entrypoint for ares_create_query()
  - configure: clock_gettime workaround
  - docs: Convert INSTALL to MarkDown and tweak
  - ares_process: Fix return type of socket_create function (Win32 warning)
  - docs: Fixed references to ares_set_local_ip4 and ares_set_local_ip6
  - Windows DNS server sorting
  - Use ares_socklen_t instead of socket_t
  - ares_create_query: Use ares_free, not naked free
  - msvc_ver.inc support most recent Visual Studio 2017
  - acountry: Convert char from ISO-8859-1 to UTF-8
  - ares_expand_name: Limit number of indirections
  - configure: Do not check for ar if specified manually
  - Added support for Windows DNS Suffix Search List
  - ares.h: Support compiling with QNX
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Feb 10 2017 Paul Howarth <paul@city-fan.org> - 1.12.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Sep 30 2016 Paul Howarth <paul@city-fan.org> - 1.12.0-1.0.cf
- Update to 1.12.0
  - api: Add ARES_OPT_NOROTATE optmask value
  - CVE-2016-5180: ares_create_query single byte out of buffer write
  - configure: Acknowledge --disable-tests
  - man pages: Fix typos detected by Lintian
  - test: Add missing #includes for dns-proto.cc
  - test: Avoid in6addr_* constants
  - test: Build with MinGW on AppVeyor
  - Makefile.m32: Add support for extra flags
  - Makefile.m32: Add support for CROSSPREFIX
  - configure: Check if tests can get built before enabled
  - ares_library_cleanup: Reset ares_realloc too
  - ahost.c: Add cast to fix C++ compile
  - test: Only pass unused args to GoogleTest
  - build: Commonize MSVC version detection
  - msvc_ver.inc: Support Visual Studio 2015 Update 1, 2, 3
  - test: For AF_UNSPEC, return CNAME only for AAAA, but valid A record
  - ares_getnameinfo: Explicitly clear struct servent before use
  - test: Update fuzzing function prototype
  - init: Fix nsort initialization
  - test: add fuzzing check script to tests
  - web: http => https
  - read_tcp_data: Remove superfluous NULL check
  - LICENSE.md: Add a stand-alone license file
  - SECURITY.md: Suggested "security process" for the project
  - ares_init_options: Only propagate init failures from options
  - headers: Remove checks for and defines of variable sizes
  - test: Fix gMock to work with gcc ≥ 6.x

* Fri Feb 19 2016 Paul Howarth <paul@city-fan.org> - 1.11.0-1.0.cf
- Update to 1.11.0
  - Add a unit test suite
  - Allow builds with code coverage with --enable-code-coverage configure option
  - Allow library-wide override of malloc/free
  - Allow multiple -s options to the ahost command
  - api: Expose the ares_library_initialized() function
  - api: Add ares_set_sortlist(3) entrypoint
  - api: Add entrypoints to allow use of per-server ports
  - api: Introduce 'ares_parse_txt_reply_ext`
  - api: Add ares_set_socket_configure_callback()
  - timeadd: Make static
  - timeoffset: Made static and private
  - nowarn: Use <limits.h> instead of configure for size of long
  - single_domain: Invalid memory access for empty string input
  - ares_build.h: Fix building on 64-bit powerpc
  - Allow specification of search domain in ahost
  - Don't override explicitly specified search domains
  - ares_parse_soa_reply: Do not leak rr_name on allocation failure
  - Update ahost man page to describe -s option
  - host_callback: Fall back to AF_INET on searching with AF_UNSPEC
  - Add -t u option to ahost
  - CONTRIBUTING: Added
  - ares_set_servers_csv: Fix NULL dereference
  - Fix integer shift overflow if both tcp_socket and udp_socket are set
  - Fix acountry memory leak
  - lookup_service: Prevent tmpbuf from overrunning
  - ares_getnameinfo.3: There is no ares_getaddrinfo
  - init_by_defaults: Continue loop if space for hostname not large enough
  - Destroy options if ares_save_options fails
  - ares__read_line: free buf on realloc failure
  - Added define for visual studio 2013
  - windows: Fix slow DNS lookup issue
  - Use libresolv to initialize cares on iPhone targets
  - buildconf: Remove check for libtool, it only requires libtoolize
  - init_by_resolv_conf: Don't exit loop early leaving uninitialized entries
  - ahost: Check the select() return code
  - configure_socket: Explicitly ignore return code
  - read_tcp_data: Don't try to use NULL pointer after malloc failure
  - Distribute all man pages
  - ares_expand_name: Check for valid bits in label length
  - ares__read_line: Clear buf pointer on realloc failure
  - process_answer: Fix things up correctly when removing EDNS option
  - ares_parse_txt_reply: Propagate errors from per-substring loop
  - ares_gethostbyname: Don't leak valid-but-empty hostent
  - ares_init_options: Don't lose init failure
  - ares_dup: Clear new channel on failure
  - config_sortlist: Free any existing sortlist on (re)alloc failure
  - ares_striendstr: Fix so non-NULL return can happen
  - bitncmp: Update comment to match code behaviour
  - ares_set_servers_csv.3: Make return type match code
  - init_by_resolv_conf: Ignore 'fopen' errors to use default values
  - Use "resolve" as synonym of "dns" in nsswitch.conf
  - ares_win32_init: Make LoadLibrary work when using UNICODE too
  - dist: Distribute README.md
  - configure: Build silently by default
  - ares_dup.3: Remove mention of nonexistent function
- Drop multilib patch, no longer needed
- Avoid trying to run the test suite for now since Fedora gmock/gtest seems to
  be borked
- Add upstream support for disabling tests
  (https://github.com/c-ares/c-ares/issues/44)

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.10.0-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 1.10.0-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.10.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 1.10.0-3.0.cf
- Drop %%defattr, redundant since rpm 4.4

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.10.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun May 12 2013 Paul Howarth <paul@city-fan.org> - 1.10.0-1.0.cf
- Update to 1.10.0
  - Added ares_create_query(), to be used instead of ares_mkquery()
  - ares_inet_ntop() and ares_inet_pton() are now recognized c-ares functions
  - Include the ares_parse_soa_reply.* files in the tarball
  - read_udp_packets: bail out loop on bad sockets
  - get_DNS_AdaptersAddresses: fix IPv6 parsing
  - adig: perror() doesn't work for socket errors on windows
  - ares_parse_aaaa_reply: fix memory leak
  - setup_once.h: HP-UX <sys/socket.h> issue workaround
  - configure: several fixes
  - config-dos.h: define strerror() to strerror_s_() for High-C
  - config-dos.h: define HAVE_CLOSE_S for MSDOS/Watt-32
  - ares_build.h.dist: enhance non-configure GCC ABI detection logic
  - ares.h: stricter CARES_EXTERN linkage decorations logic
  - ares_cancel(): cancel requests safely
  - Protocol parsing: check input data more strictly
  - Library init: be recursive, reference count inits/cleanups
  - ares_parse_txt_reply: return a ares_txt_reply node for each sub-string
  - ares_set_servers_csv: fixed IPv6 address parsing
  - Build: fix build on msvc11
- Revert to old method of ensuring we use our compiler flags

* Sat Apr 13 2013 Paul Howarth <paul@city-fan.org> - 1.9.1-6.0.cf
- Apply some autotools fixes, but avoid the need to run autoreconf during the
  build process

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.9.1-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Aug  8 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-3.0.cf
- Include URL to the license text

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 19 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-1.0.cf
- Update to 1.9.1
  - Include the ares_parse_soa_reply.* files in the tarball

* Mon Jun 18 2012 Paul Howarth <paul@city-fan.org> - 1.9.0-1.0.cf
- Update to 1.9.0
  - Added ares_parse_soa_reply
  - Fixed libcares.pc generation for static MingW* cross builds
  - ares_dup: fixed UDP and TCP port byte order in saved options

* Sat Apr 28 2012 Paul Howarth <paul@city-fan.org> - 1.8.0-1.0.cf
- Update to 1.8.0
  - Added ares_parse_naptr_reply()
  - Handle CNAME-only in ares_parse_aaaa_reply()
  - Support multiple DNS servers on Android
  - Check for __ANDROID__ in addition to ANDROID macro
  - Port numbers: convert them to network order
  - get_iphlpapi_dns_info: fix buffer overrun
  - configure: make CURL_CHECK_DEF ignore leading whitespace
  - Segfault triggered in ares_init_options()
  - ares_getnameinfo's memcpy did not copy enough bytes
  - ares_destroy: fix segfault in ares_destroy_options()
  - CHANGES: generate from script
  - configure: fix symbol hiding usability check
- Drop UTF-8 patch, no longer needed
- Update multilib patch

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.7.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 17 2011 Paul Howarth <paul@city-fan.org> - 1.7.5-1.0.cf
- Update to 1.7.5
  - Detection of semicolon comments in resolv.conf
  - Avoid using system's inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_ntop affected by potential out of bounds write
  - Added install target to Makefile.msvc
  - Only fall back to AF_INET searches when looking for AF_UNSPEC addresses
  - Fixed ares_parse_*_reply memory leaks
  - Use correct sizeof in ares_getnameinfo()
  - IPv6-on-windows: find DNS servers correctly
  - man pages: docs for the c-ares utility programs
  - getservbyport replacement for Win CE
  - config_sortlist: (win32) missing else
  - advance_tcp_send_queue: avoid NULL ptr dereference
  - configure: fix a bashism
  - ares_expand_name: Fix encoded length for indirect root
- Rebase optflags patch to match the 1.7.5 code
- Drop upstreamed typecasts patch
- Use patch rather than scripted iconv to fix character encoding of CHANGES
- Fix Source0 URL to point at the upstream tarball
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-3.0.cf
- Apply upstream patch to fix unsafe typecasts (#695424)
- Nobody else likes macros for commands

* Sun Mar 27 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.1.cf
- Remove mention of static libraries from %%description of devel package

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec  9 2010 Paul Howarth <paul@city-fan.org> - 1.7.4-1.0.cf
- Update to 1.7.4
  - Support binding to local interface/IPs: see ares_set_local_ip4,
    ares_set_local_ip6, ares_set_local_dev
  - Fix memory leak in ares_getnameinfo
  - Add missing break that caused get_ares_servers to fail
  - Fix CNAME response parsing in ares_parse_a_reply
  - Don't copy an empty sortlist in init_by_options
  - Replace uint32_t with unsigned int to fix broken builds on a couple of
    platforms
  - Fix lookup with HOSTALIASES set
  - Fix NAPTR parsing in adig
  - Compiler warning cleanups
- Drop upstream patches, now included in release

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-3.0.cf
- Apply fixes from upstream 1.7.4 development:
  - Add missing break that caused get_ares_servers to fail
  - Fix aliasing warning in gcc 4.4.4 (at least)
  - Fix memory leak in ares_getnameinfo

* Tue Jun 15 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.1.cf
- Fix multilib file conflict in c-ares-devel (#602880)

* Fri Jun 11 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.0.cf
- Update to 1.7.3
  - Builds on Android
  - Now includes all files necessary to build it (1.7.2 lacked a file)

* Thu Jun 10 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-1.0.cf
- Update to 1.7.2
  - Added ares_parse_mx_reply()
  - ares_init: Last, not first instance of domain or search should win
  - Improve alternative definition of bool
  - Fix VS2010 compiler warnings

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-1.0.cf
- Update to 1.7.1 (added IPv6 name servers support)
- Drop IPv6 nameserver patch

* Sun Mar  7 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-3.0.cf
- Change IPv6 nameserver patch according to upstream changes
  (upstream revisions 1199,1201,1202)

* Wed Mar  3 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-2.0.cf
- Add a patch to allow usage of IPv6 nameservers
- Sync optflags patch with Fedora version

* Tue Dec  1 2009 Paul Howarth <paul@city-fan.org> - 1.7.0-1.0.cf
- Update to 1.7.0 (see RELEASE-NOTES for details)
- New header files ares_build.h and ares_rules.h to package
- Update optflags patch
- Dist tag for Rawhide no longer needs special-casing

* Wed Nov  4 2009 Paul Howarth <paul@city-fan.org> - 1.6.0-3.0.cf
- Import from Fedora
- Drop unbundled LICENSE file
- Add docs RELEASE-NOTES TODO AUTHORS

* Sat Jul 25 2009 Ville Skyttä <ville.skytta at iki.fi> - 1.6.0-3
- Patch to make upstream build system honor our CFLAGS and friends.
- Don't bother building throwaway static libs.
- Disable autotools dependency tracking for cleaner build logs and possible
  slight build speedup.
- Convert docs to UTF-8.
- Update URLs.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 22 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.6.0-1
- update to 1.6.0

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Sep 12 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.5.3-1
- update to 1.5.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.5.1-2
- Autorebuild for GCC 4.3

* Tue Feb 19 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.5.1-1
- update to 1.5.1

* Thu Aug 23 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-2
- rebuild for ppc32

* Wed Jun 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-1
- bump to 1.4.0 (resolves bugzilla 243591)
- get rid of static library (.a)

* Wed Jan 17 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.2-1
- bump to 1.3.2

* Mon Sep 11 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-2
- FC-6 bump

* Mon Jul 10 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-1
- bump to 1.3.1

* Tue Feb 28 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-2
- bump for FC-5 rebuild

* Sun Sep  4 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-1
- include LICENSE text
- bump to 1.3.0

* Tue May 31 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-4
- use dist tag to prevent EVR overlap

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-2
- fix license (MIT, not LGPL)
- get rid of libcares.la

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-1
- initial package creation

